@@ -708,7 +708,7 @@ void fastmarch_close (void)
 
 
 // creating functions that returning PyObject.
-static PyObject *eikonal(PyObject *self, PyObject *args){
+static PyObject *eikonalc(PyObject *self, PyObject *args){
   // variables for our parameters. our parameters that are coming from python will be stored in theese variables.
   int number1;
   int number2;
@@ -725,29 +725,72 @@ static PyObject *eikonal(PyObject *self, PyObject *args){
   // after parsing, we are doing our job.
 //   result = number1 + number2;
 
-
-  printf("HHHH\n");
-
-
+    float f1,f2,f3,f4,f5,f6,f7,f8,f9;
+    int f10,f11,f12,f13;
+    
 	/**initialize data input**/
     PyObject *arg1=NULL;
 //     PyObject *arg2=NULL;
     PyObject *arr1=NULL;
     int nd;
 
-    if (!PyArg_ParseTuple(args, "O", &arg1))
-        return NULL;
+//     if (!PyArg_ParseTuple(args, "Offfffffffffff", &arg1, &f2, &f3, &f4, &f5, &f6, &f7, &f8, &f9, &f10, &f11, &f12, &f13))
+//         return NULL;
+PyArg_ParseTuple(args, "Offfffffffiiii", &arg1, &f1, &f2, &f3, &f4, &f5, &f6, &f7, &f8, &f9, &f10, &f11, &f12, &f13);
 
+// PyArg_ParseTuple(args, "fffffffffffff", &f2, &f3, &f4, &f5, &f6, &f7, &f8, &f9, &f10, &f11, &f12, &f13);
+// 
+
+//  PyArg_ParseTuple(args, "f", &f2);
+//  	printf("f1=%f\n",f1);
+//  	printf("f2=%f\n",f2);
+//   	printf("f3=%f\n",f3);
+//  	printf("f4=%f\n",f4);
+//  	printf("f5=%f\n",f5);
+//   	printf("f6=%f\n",f6);
+//  	printf("f7=%f\n",f7);
+//  	printf("f8=%f\n",f8);
+//   	printf("f9=%f\n",f9);
+//  	printf("f10=%d\n",f10);
+//  	printf("f11=%d\n",f11);
+//   	printf("f12=%d\n",f12);
+//   	printf("f13=%d\n",f13);
+
+    int b1, b2, b3, n1, n2, n3, nshot, ndim, i, is,order,n123, *p;
+    float br1, br2, br3, o1, o2, o3, d1, d2, d3, slow;
+    float **s, *t, *v;
+    float x, y, z;
+    bool isvel, sweep, plane[3];
+    
+	x=f1;
+	y=f2;
+	z=f3;
+	
+	o1=f4;
+	o2=f5;
+	o3=f6;
+	
+	d1=f7;
+	d2=f8;
+	d3=f9;
+	
+	n1=f10;
+	n2=f11;
+	n3=f12;
+	
+	order=f13;
+	
+	
     arr1 = PyArray_FROM_OTF(arg1, NPY_FLOAT, NPY_IN_ARRAY);
     /*
      * my code starts here
      */
     nd=PyArray_NDIM(arr1);
-    printf("nd=%d\n",nd);
+//     printf("nd=%d\n",nd);
 // // 
     npy_intp *sp=PyArray_SHAPE(arr1);
 // // 
-    printf("array dimentsion: %ld\n",*sp);
+//     printf("array dimentsion: %ld\n",*sp);
 // 
 
 	
@@ -762,22 +805,19 @@ static PyObject *eikonal(PyObject *self, PyObject *args){
 // 	time=fopen("time.bin","wb");
 // 	printf("HHHH\n");
 
-    int b1, b2, b3, n1, n2, n3, nshot, ndim, i, is,order,n123, *p;
-    float br1, br2, br3, o1, o2, o3, d1, d2, d3, slow;
-    float **s, *t, *v;
-    bool isvel, sweep, plane[3];
+
     
-	n1=501;
-	n2=501;
-	n3=1;
-	d1=0.01;
-	d2=0.01;
-	d3=1;
-	o1=0;
-	o2=0;
-	o3=0;
+// 	n1=501;
+// 	n2=501;
+// 	n3=1;
+// 	d1=0.01;
+// 	d2=0.01;
+// 	d3=1;
+// 	o1=0;
+// 	o2=0;
+// 	o3=0;
 	isvel=true;
-	order=2;
+// 	order=2;
 	sweep=false;
 	br1=d1;
 	br2=d2;
@@ -809,9 +849,9 @@ static PyObject *eikonal(PyObject *self, PyObject *args){
 // 	/* Shot location (used if no shotfile) */
 // 	if(!sf_getfloat("yshot",&s[0][1])) s[0][1]=o2 + 0.5*(n2-1)*d2;
 // 	if(!sf_getfloat("xshot",&s[0][2])) s[0][2]=o3 + 0.5*(n3-1)*d3;
-	s[0][0]=0;
-	s[0][1]=0;
-	s[0][2]=0;
+	s[0][0]=x;
+	s[0][1]=y;
+	s[0][2]=z;
 	
 	
 // 	sf_warning("Shooting from zshot=%g yshot=%g xshot=%g",
@@ -874,44 +914,10 @@ static PyObject *eikonal(PyObject *self, PyObject *args){
 // 	sf_floatwrite (t,n123,time);
 // 	fwrite(t,1,n123*sizeof(float),time);
     }
-
-
-
-
-
-
-
-  // like before, this part is parsing our variable to a python value and returning it.
-  // in here i means we are returning an integer that comes from result variable.
-//   return Py_BuildValue("i", result);
-  
-//   PyArrayObject *meanX;
-//   meanX = (PyArrayObject *) t ;
-//   return PyArray_Return(meanX);
-//   
-
-//     PyArrayObject *X, *meanX;
-//     int axis;
-// 
-//     PyArg_ParseTuple(args, "O!i", &PyArray_Type, &X, &axis);
-//     meanX = (PyArrayObject *) PyArray_Mean(X, axis, NPY_FLOAT, NULL);
-// 	PyArrayObject *meanX;
-// 	meanX = (PyArrayObject *) t;
-//     return PyArray_Return(meanX);
-    
-//   m = PyModule_Create(&moduledef);
-//   
-//   Py_DECREF(logit);
-//   return m;
-
-
-    printf("Hello, world!\n");
-//     return PyArray_Return(arr1);
     
     PyArrayObject *vecout;
-// 	int i;
 	npy_intp dims[2];
-	dims[0]=n1*n2;dims[1]=1;
+	dims[0]=n1*n2*n3;dims[1]=1;
 	/* Parse tuples separately since args will differ between C fcns */
 	/* Make a new double vector of same dimension */
 	vecout=(PyArrayObject *) PyArray_SimpleNew(1,dims,NPY_FLOAT);
@@ -927,9 +933,9 @@ static PyObject *eikonal(PyObject *self, PyObject *args){
 	int d=vecout->dimensions[0];
 // 	vecout->data[0]=1.2;
 // 	vecout->data[1]=1.6;
-	printf("d=%d\n",d);
+// 	printf("d=%d\n",d);
 // 	printf("t=%f\n",vecout->data[0]);
-	printf("t=%f\n",(*((float*)PyArray_GETPTR1(vecout,0))));
+// 	printf("t=%f\n",(*((float*)PyArray_GETPTR1(vecout,0))));
 	
 	return PyArray_Return(vecout);
 	
@@ -939,31 +945,31 @@ static PyObject *eikonal(PyObject *self, PyObject *args){
 
 
 // documentation for each functions.
-static char eikonal_document[] = "Document stuff for eikonal...";
+static char eikonalc_document[] = "Document stuff for eikonal...";
 
 // defining our functions like below:
 // function_name, function, METH_VARARGS flag, function documents
 static PyMethodDef functions[] = {
-  {"eikonal", eikonal, METH_VARARGS, eikonal_document},
+  {"eikonalc", eikonalc, METH_VARARGS, eikonalc_document},
   {NULL, NULL, 0, NULL}
 };
 
 // initializing our module informations and settings in this structure
 // for more informations, check head part of this file. there are some important links out there.
-static struct PyModuleDef eikonalModule = {
+static struct PyModuleDef eikonalcModule = {
   PyModuleDef_HEAD_INIT, // head informations for Python C API. It is needed to be first member in this struct !!
-  "eikonal",  // module name
+  "eikonalc",  // module name
   NULL, // means that the module does not support sub-interpreters, because it has global state.
   -1,
   functions  // our functions list
 };
 
 // runs while initializing and calls module creation function.
-PyMODINIT_FUNC PyInit_eikonal(void){
+PyMODINIT_FUNC PyInit_eikonalc(void){
 
 //   return PyModule_Create(&eikonalModule);
   
-    PyObject *module = PyModule_Create(&eikonalModule);
+    PyObject *module = PyModule_Create(&eikonalcModule);
     import_array();
     return module;
 }
